@@ -16,8 +16,8 @@ conc.test <- function(u, ina, rads = FALSE) {
   ## if the data are in degrees we transform them into radians
   x1 <- cos(u)
   x2 <- sin(u)
-  Ci <- Rfast::group.mean(x1, ina)  ## rowsum(x1, ina) / ni
-  Si <- Rfast::group.mean(x2, ina)  ## rowsum(x2, ina) / ni
+  Ci <- Rfast::group(x1, ina, method = "mean")  ## rowsum(x1, ina) / ni
+  Si <- Rfast::group(x2, ina, method = "mean")  ## rowsum(x2, ina) / ni
   Rbi <- sqrt( Ci^2 + Si^2 )
   ## Ri is the mean resultant length of each group
   C <- sum( Ci * ni ) / n   ### sum(x1)/n
