@@ -18,15 +18,15 @@ iag.reg <- function(y, x, con = TRUE, xnew = NULL, tol = 1e-06) {
    }
 
   ini <- solve(crossprod(x), crossprod(x, y))  ## initial values for the beta
-  options(warn = -1)
+  oop <- options(warn = -1) 
   val1 <-  nlm(regiag, ini, y = y, x = x, iterlim = 1000)
   val2 <-  nlm(regiag, val1$estimate, y = y, x = x, iterlim = 1000)
   while (val1$minimum - val2$minimum > tol) {
     val1 <- val2
     val2 <-  nlm(regiag, val1$estimate, y = y, x = x, iterlim = 1000)
   }
-
   da <- optim(val2$estimate, regiag, y = y, x = x, control = list(maxit = 10000), hessian = TRUE)
+  on.exit( options(oop) )
   be <- matrix(da$par, ncol = 3)
   seb <- sqrt( diag( solve(da$hessian) ) )
   seb <- matrix(seb, ncol = 3)
